.. _contributors_index:

#########################################
FitBenchmarking Contributor Documentation
#########################################

Thank you for being a contributor to the FitBenchmarking project.
Here you will find all you need in order to get started.

.. toctree::
    :titlesonly:
    :maxdepth: 2
    :caption: Contents:

    guidelines
    workflow
    structure
    Module Index <module_index/fitbenchmarking>

